==> nextcloud-14.0.1.tgz: nextcloud/apps/updatenotification/l10n/is.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} er í boði. Fáðu frekari upplýsingar um hvernig á að uppfæra.",
    "Update notifications" : "Tilkynningar um uppfærslu",
    "Channel updated" : "Rás uppfærð",
    "The update server could not be reached since %d days to check for new updates." : "Ekki hefur verið hægt að nálgast uppfærsluþjóninn í %d daga til að athuga með nýjar uppfærslur.",
    "Please check the Nextcloud and server log files for errors." : "Skoðaðu hvort einhver villuboð séu í annálaskrám Nextcloud þjónsins.",
    "Update to %1$s is available." : "Uppfærsla fyrir %1$s er tiltæk.",
    "Update for %1$s to version %2$s is available." : "Uppfærsla %1$s í útgáfu %2$s er tiltæk.",
    "Update for {app} to version %s is available." : "Uppfærsla fyrir {app} í útgáfu %s er tiltæk.",
    "Update notification" : "Tilkynning um uppfærslu",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Birtir tilkynningar um uppfærslur fyrir Nextcloud og sér um SSO-innskráningu fyrir uppfærslustýringuna.",
    "Apps with available updates" : "Forrit með tiltækar uppfærslur",
    "Open updater" : "Opna uppfærslustýringu",
    "What's new?" : "Nýtt á döfinni?",
    "The update check is not yet finished. Please refresh the page." : "Athugun á uppfærslum er ekki ennþá lokið. Endurlestu síðuna.",
    "A non-default update server is in use to be checked for updates:" : "Uppfærsluþjónn sem ekki er sjálfgefinn er núna í notkun til að athuga með uppfærslur:",
    "Update channel:" : "Uppfærslurás:",
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "Þú getur alltaf uppfært í nýrri útgáfu eða tilraunaútgáfurás. En þú getur aldrei niðurfært í stöðugri rás.",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Athugaðu að það getur tekið nokkurn tíma áður en nýjar útgáfur birtast hér. Við dreifum útgáfum yfir tíma auk þess sem stundum er útgáfum sleppt ef í þeim finnast hnökrar.",
    "Notify members of the following groups about available updates:" : "Tilkynna meðlimum eftirfarandi hópa um tiltækar uppfærslur:",
    "Only notification for app updates are available." : "Eingöngu eru eru tiltækar tilkynningar fyrir uppfærslur forrita.",
    "The selected update channel does not support updates of the server." : "Valda uppfærslurásin styður ekki uppfærslur fyrir vefþjóninn.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Ný útgáfa er tiltæk: <strong>{newVersionString}</strong>",
    "Checked on {lastCheckedDate}" : "Athugað þann {lastCheckedDate}",
    "Checking apps for compatible updates" : "Athuga forrit vegna hugsanlegra uppfærslna",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Gakktu úr skugga um að í config.php sé <samp>appstoreenabled</samp> ekki sett sem ósatt/false.",
    "Could not connect to the appstore or the appstore returned no updates at all. Search manually for updates or make sure your server has access to the internet and can connect to the appstore." : "Gat ekki tengst við forritabúðina eða að í henni eru engar uppfærslur. Leitaðu handvirkt að uppfærslum, eða gakktu úr skugga um að þjónninn þinn sé með aðgang að internetinu og geti tengst forritabúðinni.",
    "<strong>All</strong> apps have an update for this version available" : "<strong>Öll</strong> forrit eru með uppfærslu tiltæka fyrir þessa útgáfu",
    "_<strong>%n</strong> app has no update for this version available_::_<strong>%n</strong> apps have no update for this version available_" : ["<strong>%n</strong> forrit eru með uppfærslu tiltæka fyrir þessa útgáfu","<strong>%n</strong> forrit eru með uppfærslu tiltæka fyrir þessa útgáfu"],
    "<strong>production</strong> will always provide the latest patch level, but not update to the next major release immediately. That update usually happens with the second minor release (x.0.2)." : "<strong>vinnsla</strong> mun alltaf vera á nýjasta stigi endurbóta (öryggisviðbætur o.fl.), en ekki uppfærast samstundis í næstu aðalútgáfu. Sú uppfærsla á sér yfirleitt stað við undirútgáfu númer tvö (x.0.2).",
    "<strong>stable</strong> is the most recent stable version. It is suited for regular use and will always update to the latest major version." : "<strong>stöðug</strong> er nýjasta stöðuga útgáfan. Hún hentar fyrir alla venjulega notkun og er alltaf uppfærð í nýjustu aðalútgáfu.",
    "<strong>beta</strong> is a pre-release version only for testing new features, not for production environments." : "<strong>beta</strong> er for-útgáfa sem einungis er hugsuð til að prófa nýja eiginleika, og er alls ekki ætluð fyrir alvöru vinnslu.",
    "View changelog" : "Skoða breytingaannál",
    "Could not start updater, please try the manual update" : "Gat ekki ræst uppfærslustýringu, prófaðu að uppfæra handvirkt",
    "A new version is available: %s" : "Ný útgáfa er tiltæk: %s",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Útgáfunni sem þú ert að keyra er ekki legur viðhaldið. Uppfærðu í studda útgáfu við fyrsta tækifæri.",
    "Download now" : "Sækja núna",
    "Your version is up to date." : "Útgáfan þín er af nýjustu gerð.",
    "Checked on %s" : "Athugað þann %s",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Valda uppfærslurásin gerir úreltar sértækar tilkynningar fyrir vefþjóninn."
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> nextcloud-18.0.4.tgz: nextcloud/apps/updatenotification/l10n/is.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} er í boði. Fáðu frekari upplýsingar um hvernig á að uppfæra.",
    "Channel updated" : "Rás uppfærð",
    "Update notifications" : "Tilkynningar um uppfærslu",
    "The update server could not be reached since %d days to check for new updates." : "Ekki hefur verið hægt að nálgast uppfærsluþjóninn í %d daga til að athuga með nýjar uppfærslur.",
    "Please check the Nextcloud and server log files for errors." : "Skoðaðu hvort einhver villuboð séu í annálaskrám Nextcloud þjónsins.",
    "Update to %1$s is available." : "Uppfærsla fyrir %1$s er tiltæk.",
    "Update for %1$s to version %2$s is available." : "Uppfærsla %1$s í útgáfu %2$s er tiltæk.",
    "Update for {app} to version %s is available." : "Uppfærsla fyrir {app} í útgáfu %s er tiltæk.",
    "Update notification" : "Tilkynning um uppfærslu",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Birtir tilkynningar um uppfærslur fyrir Nextcloud og sér um SSO-innskráningu fyrir uppfærslustýringuna.",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Útgáfunni sem þú ert að keyra er ekki legur viðhaldið. Uppfærðu í studda útgáfu við fyrsta tækifæri.",
    "Apps missing updates" : "Forrit sem vantar uppfærslur",
    "View in store" : "Skoða í hugbúnaðarsafni",
    "Apps with available updates" : "Forrit með tiltækar uppfærslur",
    "Open updater" : "Opna uppfærslustýringu",
    "Download now" : "Sækja núna",
    "What's new?" : "Hvað er nýtt á döfinni?",
    "The update check is not yet finished. Please refresh the page." : "Athugun á uppfærslum er ekki ennþá lokið. Endurlestu síðuna.",
    "Your version is up to date." : "Útgáfan þín er af nýjustu gerð.",
    "A non-default update server is in use to be checked for updates:" : "Uppfærsluþjónn sem ekki er sjálfgefinn er núna í notkun til að athuga með uppfærslur:",
    "Update channel:" : "Uppfærslurás:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Þú getur alltaf uppfært í nýrri útgáfu. En þú getur aldrei niðurfært í stöðugri útgáfu.",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Athugaðu að það getur tekið nokkurn tíma áður en nýjar útgáfur birtast hér. Við dreifum útgáfum yfir tíma auk þess sem stundum er útgáfum sleppt ef í þeim finnast hnökrar.",
    "Notify members of the following groups about available updates:" : "Tilkynna meðlimum eftirfarandi hópa um tiltækar uppfærslur:",
    "Only notification for app updates are available." : "Eingöngu eru eru tiltækar tilkynningar fyrir uppfærslur forrita.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Valda uppfærslurásin gerir úreltar sértækar tilkynningar fyrir vefþjóninn.",
    "The selected update channel does not support updates of the server." : "Valda uppfærslurásin styður ekki uppfærslur fyrir vefþjóninn.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Ný útgáfa er tiltæk: <strong>{newVersionString}</strong>",
    "Checked on {lastCheckedDate}" : "Athugað þann {lastCheckedDate}",
    "Checking apps for compatible updates" : "Athuga forrit vegna hugsanlegra uppfærslna",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Gakktu úr skugga um að í config.php sé <samp>appstoreenabled</samp> ekki sett sem ósatt/false.",
    "Could not connect to the appstore or the appstore returned no updates at all. Search manually for updates or make sure your server has access to the internet and can connect to the appstore." : "Gat ekki tengst við forritabúðina eða að í henni eru engar uppfærslur. Leitaðu handvirkt að uppfærslum, eða gakktu úr skugga um að þjónninn þinn sé með aðgang að internetinu og geti tengst forritabúðinni.",
    "<strong>All</strong> apps have an update for this version available" : "<strong>Öll</strong> forrit eru með uppfærslu tiltæka fyrir þessa útgáfu",
    "View changelog" : "Skoða breytingaannál",
    "Enterprise" : "Fyrirtæki",
    "Stable" : "Stöðug",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Nýjasta stöðuga útgáfan. Hún hentar fyrir alla venjulega notkun og er alltaf uppfærð í nýjustu aðalútgáfu.",
    "Beta" : "BETA-prófunarútgáfa",
    "A pre-release version only for testing new features, not for production environments." : "For-útgáfa sem einungis er hugsuð til að prófa nýja eiginleika, og er alls ekki ætluð fyrir alvöru vinnslu.",
    "_<strong>%n</strong> app has no update for this version available_::_<strong>%n</strong> apps have no update for this version available_" : ["<strong>%n</strong> forrit eru með uppfærslu tiltæka fyrir þessa útgáfu","<strong>%n</strong> forrit eru með uppfærslu tiltæka fyrir þessa útgáfu"],
    "Production" : "Vinnsluútgáfa",
    "Will always provide the latest patch level, but not update to the next major release immediately. That update usually happens with the second minor release (x.0.2) and only if the instance is already on the latest minor version." : "vinnsla mun alltaf vera á nýjasta stigi endurbóta (öryggisviðbætur o.fl.), en ekki uppfærast samstundis í næstu aðalútgáfu. Sú uppfærsla á sér yfirleitt stað við undirútgáfu númer tvö (x.0.2) og þá aðeins ef þjónninn er þegar með síðustu undirútgáfu."
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
